function h=daub(L,type)
%DAUB Daubechies filter
% DAUB(L) or DAUB(L,'min') produces the minimum phase Daubechies low-pass
% filter of length L
% DAUB(L,'lin') produces the Daubechies filter whose phase response is
% closest to linear (as determined by PHASEVAR)
%
% See also FACTOR, PHASEVAR, REMEZWAV, WFILTER from the SIMPA library

% For MATLAB 4.1
% Author: Olivier Rioul March 16 1994

% References:
% Ingrid Daubechies, Orthonormal bases of compactly supported wavelets,
%    Comm. Pure Appl. Math., Vol. XLI, No. 7, pp. 909-996, 1988
% Ingrid Daubechies, Orthonormal bases of compactly supported wavelets II,
%    Variations on a theme, SIAM J. Math. Anal., Vol. 24, 1993.

if length(L)~=1, error('input must be a scalar'), end
if imag(L)~=0, error('input must be real'), end
if rem(L,2), error('input must be even'), end
[p,r]=remezwav(L,L/2);
if nargin==1, type='min'; end
if strcmp(type,'min')
 h=factor(r,'min');
elseif strcmp(type,'lin')
 h=factor(r,'lin');
else
 error('type is not valid.');
end
