function r=reg(h,K)
%REG Hoelder Regularity
% REG(H) gives a sharp upper bound for the Hoelder regularity order
% of low-pass filter H (it may be negative)
%
% REG(H,k) forces the number of zeros at z==-1 in H to k. By default,
% k is estimated by successive division with remainders <1e-3
%
% See also SOBREG in the SIMPA Toolbox

% For MATLAB 4.1
% Author: Olivier Rioul March 16 1994

% References:
% Olivier Rioul, Simple regularity criteria for subdivision schemes,
%    SIAM J. Math. Anal., Vol. 23, No. 6, pp. 1544-1576, Nov. 1992

if min(size(h))~=1, error('input must be a vector'), end
if any(imag(h)), error('input must be real'), end
h=h(:)';


tol=1e-3;
if nargin==2
 for k=1:K
  [h,r]=deconv(h,[1 1]);
  if max(abs(r))>tol
    fprintf('Warning in reg: remainder=%g\n',max(abs(r)));
  end
 end
else
 K=0;
 [q,r]=deconv(h,[1 1]);  % do .. while
 while max(abs(r))<tol
  h=q; K=K+1; [q,r]=deconv(h,[1 1]);
 end
 fprintf('%g zeroes at z==-1 in filter\n',K);
end

h=h./sum(h); L=length(h);

if L==1, r=K-1;
else
 toeplitz([h zeros(1,L)]',[h(1) zeros(1,2*L-1)]);
 H=ans(3:2:2*L-3,2:L-1); % taille (L-2)x(L-2)
 r=K-1-log(max([abs(h(1));abs(h(L));abs(eig(H))]))/log(2);
end
