function r=sobreg(h,K)
%SOBREG
% SOBREG(H) gives optimal Sobolev regularity order of low-pass filter H
%
% SOBREG(H,k) forces the number of zeros at z==-1 in H to k. By default,
% k is estimated by successive division with remainders <1e-3
%
% See also REG in the SIMPA Toolbox

% For MATLAB 4.1
% Author: Olivier Rioul March 16 1994

% References:
% Olivier Rioul, Simple regularity criteria for subdivision schemes,
%    SIAM J. Math. Anal., Vol. 23, No. 6, pp. 1544-1576, Nov. 1992

if min(size(h))~=1, error('input must be a vector'), end
if any(imag(h)), error('input must be real'), end
h=h(:)'; 

tol=1e-3;
if nargin==2
 for k=1:K
  [h,r]=deconv(h,[1 1]);
  if max(abs(r))>tol
    fprintf('Warning in reg: remainder=%g\n',max(abs(r)));
  end
 end
else
 K=0;
 [q,r]=deconv(h,[1 1]);  % do .. while
 while max(abs(r))<tol
  h=q; K=K+1; [q,r]=deconv(h,[1 1]);
 end
 fprintf('%g zeroes at z==-1 in filter\n',K);
end

p=square(h); K=2*K;
L=length(p);
if (~rem(L,2) | rem(K,2))
 error('Bug in sobreg')
end
if L==1, r=K/2-1;
else 
 p=p./sum(p);          % Normalize
 p(2*L)=0;             % Pad w/ zeros
 ind=2:L-1; P=p(ind);  % 1st line of P (length L-2)
 for n=1:(L-3)/2    % matrix P, line by line
  P = [P; p(ind+2*n)];
 end
 P1=P(:,1:(L-3)/2);     % 1st half of P
 P(:,1:(L-3)/2)=[];
 P(:,2:(L-1)/2)=P(:,2:(L-1)/2)+...
 P1(:,(L-3)/2:-1:1); % fold matrix

 r=(K-log(max(abs(eig(P))))/log(2)-2)/2;
end
