function h=wfilter(L,K,B,type)
%WFILTER Orthonormal wavelet filter
% WFILTER(L,K,B) or WFILTER(L,K,B,'min') produces the minimum-phase orthonormal
% wavelet low-pass filter of length L with K zeros at the Nyquist frequency
% (z==-1), and maximally frequency selective given normalized transition
% bandwidth B. (See REMEZWAV)
%
% WFILTER(L,K,B,'lin') produces the wavelet filter whose phase response is
% closest to linear (as determined by PHASEVAR)
%
% WFILTER(L,L/2,B,'type') is equivalent to DAUB(L,'type')
%
% See also DAUB, FACTOR, PHASEVAR, REMEZWAV from the SIMPA library

% For MATLAB 4.1
% Author: Olivier Rioul March 16 1994

% References:
% Olivier Rioul and Pierre Duhamel, A Remez exchange algorithm for
%    orthonormal wavelets, IEEE Trans. CAS II, To appear.
% Ingrid Daubechies, Orthonormal bases of compactly supported wavelets,
%    Comm. Pure Appl. Math., Vol. XLI, No. 7, pp. 909-996, 1988
% Mark J. T. Smith and Thomas P. Barnwell III, Exact reconstruction
%    techniques for tree-structured subband coders, IEEE Trans. ASSP,
%    Vol. 34, No. 3, pp. 434-441, 1986.

if length(L)~=1, error('input must be a scalar'), end
if imag(L)~=0, error('input must be real'), end
if rem(L,2), error('input must be even'), end
[p,r]=remezwav(L,K,B);
if nargin==3, type='min'; end
if strcmp(type,'min')
 h=factor(r,'min');
elseif strcmp(type,'lin')
 h=factor(r,'lin');
else
 error('type is not valid.');
end
